MainWrapper class

Inheritance

Constructors

MainWrapper({Key? key, Widget? child, required List<NavigationItem> items, required List<String> routePaths, required List<Widget> pages, Future<bool> onTabTap(BuildContext context, int index)?})
const

Properties

child Widget?
final
hashCode int
The hash code for this object.
no setterinherited
items List<NavigationItem>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTabTap Future<bool> Function(BuildContext context, int index)?
final
pages List<Widget>
final
routePaths List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → ConsumerStatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → ConsumerState<MainWrapper>
Creates the mutable state for this widget at a given location in the tree.
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited