SliverProfileHeader class

Inheritance

Constructors

SliverProfileHeader({required String title, required String imageCoverUrl, Uint8List? imageCoverBytes, String? imageCoverHeroTag, required String imageProfileUrl, Uint8List? imageProfileBytes, String? imageProfileHeroTag, VoidCallback? onBackTap, VoidCallback? onSearchTap, VoidCallback? onMoreTap, VoidCallback? onProfileImageTap, VoidCallback? onCoverImageTap})

Properties

bottomHeight double
final
collapsedHeight double
final
expandedHeight double
final
extraRadius double
final
hashCode int
The hash code for this object.
no setterinherited
imageCoverBytes Uint8List?
final
imageCoverHeroTag String?
final
imageCoverUrl String
final
imageProfileBytes Uint8List?
final
imageProfileHeroTag String?
final
imageProfileUrl String
final
maxExtent double
The size of the header when it is not shrinking at the top of the viewport.
no setteroverride
minExtent double
The smallest size to allow the header to reach, when it shrinks at the start of the viewport.
no setteroverride
onBackTap VoidCallback?
final
onCoverImageTap VoidCallback?
final
onMoreTap VoidCallback?
final
onProfileImageTap VoidCallback?
final
onSearchTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showOnScreenConfiguration PersistentHeaderShowOnScreenConfiguration?
Specifies how floating headers and pinned headers should behave in response to RenderObject.showOnScreen calls.
no setterinherited
snapConfiguration FloatingHeaderSnapConfiguration?
Specifies how floating headers should animate in and out of view.
no setterinherited
stretchConfiguration OverScrollHeaderStretchConfiguration?
Specifies an AsyncCallback and offset for execution.
no setterinherited
title String
final
vsync TickerProvider?
A TickerProvider to use when animating the header's size changes.
no setterinherited

Methods

build(BuildContext context, double shrinkOffset, bool overlapsContent) Widget
The widget to place inside the SliverPersistentHeader.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant SliverPersistentHeaderDelegate oldDelegate) bool
Whether this delegate is meaningfully different from the old delegate.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited